<?php
/**
 * Photo Fusion Pro Theme Customizer
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function photo_fusion_pro_customize_register( $wp_customize ) {
	$options = photo_fusion_pro_get_theme_options();


	// Load customize active callback functions.
	require get_template_directory() . '/inc/customizer/active-callbacks.php';

	// Load validation callback functions.
	require get_template_directory() . '/inc/customizer/validation.php';

	// Load customize partial functions.
	require get_template_directory() . '/inc/customizer/partial.php';

	// Load custom controls.
	require get_template_directory() . '/inc/customizer/custom-controls.php';

	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	$wp_customize->get_control( 'custom_logo' )->description = esc_html__( 'The recommended size for the logo is 120px by 70px.', 'photo-fusion-pro' );

	// Load additonal menu options.
	require get_template_directory() . '/inc/customizer/sections/color.php';

	// Load additonal menu options.
	require get_template_directory() . '/inc/customizer/sections/menu.php';

	/**
	* Common Options
	*/
	// Add panel for common options
	$wp_customize->add_panel( 'photo_fusion_pro_theme_options_panel' , array(
	    'title'      => esc_html__( 'Theme Options','photo-fusion-pro' ),
	    'description'=> esc_html__( 'Photo Fusion Theme Options.', 'photo-fusion-pro' ),
	    'priority'   => 150,
	) );

	if ( version_compare( $GLOBALS['wp_version'], '4.7', '<' ) ) {
		// Load custom-css options.
		require get_template_directory() . '/inc/customizer/theme-options/custom-css.php';
	}
	// Load excerpt options.
	require get_template_directory() . '/inc/customizer/theme-options/excerpt.php';

	// Load footer options.
	require get_template_directory() . '/inc/customizer/theme-options/footer.php';

	// Load pagination options.
	require get_template_directory() . '/inc/customizer/theme-options/pagination.php';

	// Load layout options.
	require get_template_directory() . '/inc/customizer/theme-options/layout.php';

	// Load loader options.
	require get_template_directory() . '/inc/customizer/theme-options/loader.php';

	// Load color options.
	require get_template_directory() . '/inc/customizer/theme-options/homepage-static.php';

	// typography
	require get_template_directory() . '/inc/customizer/theme-options/typography.php';

	/**
	* Theme Options for sections
	*/
	// Add panel for different sections
	$wp_customize->add_panel( 'photo_fusion_pro_sections_panel' , array(
	    'title'      => esc_html__( 'Homepage Sections','photo-fusion-pro' ),
	    'description'=> esc_html__( 'Photo Fusion available sections.', 'photo-fusion-pro' ),
	    'priority'   => 130,
	) );

	// Load slider options.
	require get_template_directory() . '/inc/customizer/sections/slider.php';

	// Load about section options.
	require get_template_directory() . '/inc/customizer/sections/about.php';

	// Load photo gallery us section options.
	require get_template_directory() . '/inc/customizer/sections/photo-gallery.php';

	// Load portfolio section options.
	require get_template_directory() . '/inc/customizer/sections/portfolio.php';

	// Load blog section options.
	require get_template_directory() . '/inc/customizer/sections/blog.php';

	// Load page gallery options.
	require get_template_directory() . '/inc/customizer/sections/gallery-page.php';

	// Load counter options.
	require get_template_directory() . '/inc/customizer/sections/counter.php';

	// Load contact options.
	require get_template_directory() . '/inc/customizer/sections/contact.php';

	// Add  page template panel
	$wp_customize->add_panel( 'photo_fusion_pro_page_template',
		array(
			'title'      			=> esc_html__( 'Page Template', 'photo-fusion-pro' ),
			'priority'   			=> 100,
			'capability' 			=> 'edit_theme_options',
		)
	);

	/**
	* Reset section
	*/
	// Add reset enable section
	$wp_customize->add_section( 'photo_fusion_pro_reset_section', array(
		'title'             => esc_html__( 'Reset all settings','photo-fusion-pro' ),
		'description'       => esc_html__( 'Caution: All settings will be reset to default. Refresh the page after clicking Save & Publish.', 'photo-fusion-pro' ),
	) );

	// Add reset enable setting and control.
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[reset_options]', array(
		'default'           => $options['reset_options'],
		'sanitize_callback' => 'photo_fusion_pro_sanitize_checkbox',
		'transport'			  => 'postMessage'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[reset_options]', array(
		'label'             => esc_html__( 'Check to reset all settings', 'photo-fusion-pro' ),
		'section'           => 'photo_fusion_pro_reset_section',
		'type'              => 'checkbox',
	) );
}
add_action( 'customize_register', 'photo_fusion_pro_customize_register' );

/*
 * Load customizer sanitization functions.
 */
require get_template_directory() . '/inc/customizer/sanitize.php';

/**
 * Enqueue styles on customizer preview.
 */
function photo_fusion_pro_customizer_styles() {
	if ( is_customize_preview() ) {
	   // Add fontawesome
		wp_enqueue_style( 'fontawesome', get_template_directory_uri() . '/assets/plugins/fontawesome/css/font-awesome.min.css', '', '4.6.3' );

		// Add custom css for customizer
		wp_enqueue_style( 'photo-fusion-pro-customizer', get_template_directory_uri() . '/assets/css/customizer.min.css' );
	}
}
add_action( 'customize_controls_print_styles', 'photo_fusion_pro_customizer_styles' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function photo_fusion_pro_customize_preview_js() {
	wp_enqueue_script( 'photo_fusion_pro_customizer', get_template_directory_uri() . '/assets/js/customizer.min.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'photo_fusion_pro_customize_preview_js' );


function photo_fusion_pro_inline_css() {
	$options            = photo_fusion_pro_get_theme_options();

	$counter_bg_image   = ! empty( $options['counter_bg_image'] ) ? $options['counter_bg_image'] : get_template_directory_uri(). '/assets/uploads/background-01.jpg';
	$animated_layout    = $options['site_animation_layout'];

	// Declare variable to store custom css
	$photo_fusion_pro_custom_css = '';
	$css = '';
	// Check if the custom CSS feature of 4.7 exists
	if ( function_exists( 'wp_update_custom_css_post' ) ) {
	    // Migrate any existing theme CSS to the core option added in WordPress 4.7.
	    if( !empty( $options['custom_css'] ) )
	    	$css = $options['custom_css'];
	    
	    if ( $css ) {
	        $core_css = wp_get_custom_css(); // Preserve any CSS already added to the core option.
	        $return = wp_update_custom_css_post( $core_css . $css );
			
	        if ( ! is_wp_error( $return ) ) {
	            // Remove the old theme_mod, so that the CSS is stored in only one place moving forward.
	   			$options['custom_css'] = '';
				set_theme_mod( 'photo_fusion_pro_theme_options', $options );
	        }
	    }
	} else {
	    // Back-compat for WordPress < 4.7.
		if ( isset( $options['custom_css'] ) ) {
			$photo_fusion_pro_custom_css = $options['custom_css'];
		}
	}

	$css = '
		/* counter background image */
		#counter {
		    background-image: url("'.esc_url( $counter_bg_image ).'");
		    background-size: cover;
		    background-repeat : no-repeat;
		}
	' . $photo_fusion_pro_custom_css;
	if ( $animated_layout != true ){
		$css .= '.os-animation { opacity: 1; }';
	}

	if ( 'color-picker' == $options['color_theme_type'] ) {
		$theme_color = ! empty( $options['theme_color'] ) ? $options['theme_color'] : ''; 
		$theme_button_hover_color = ! empty( $options['theme_button_hover_color'] ) ? $options['theme_button_hover_color'] : ''; 
		$theme_post_meta_color = ! empty( $options['theme_post_meta_color'] ) ? $options['theme_post_meta_color'] : ''; 
		$css .= '
            .btn.fill .btn-hide,
            .woocommerce #respond input#submit:hover, 
            .woocommerce a.button:hover, 
            .woocommerce button.button:hover, 
            .woocommerce input.button:hover, 
            .woocommerce #respond input#submit:focus, 
            .woocommerce a.button:focus, 
            .woocommerce button.button:focus, 
            .woocommerce input.button:focus, 
            .woocommerce #respond input#submit.alt:hover, 
            .woocommerce a.button.alt:hover, 
            .woocommerce button.button.alt:hover, 
            .woocommerce input.button.alt:hover, 
            .woocommerce #respond input#submit.alt:focus, 
            .woocommerce a.button.alt:focus, 
            .woocommerce button.button.alt:focus, 
            .woocommerce input.button.alt:focus {
                background-color: ' . esc_attr( $theme_button_hover_color ) . ';
            }
        ';

		$css .= '
            .main-navigation ul li.current-menu-item > a, 
            .main-navigation ul li a:hover,
            .layer-1 h5,
            .main-slider .controls .fa,
            .cycle-pager span,
            .picker_close, 
            .picker_close:hover, 
            .picker_close:focus,
            .color-switcher .font-family li.active a, 
            .color-switcher .font-family li a:hover,
            .blog-wrapper .blog-content .blog-title h4:hover, 
            .blog-wrapper .blog-content .entry-header .entry-title:hover,
            .address-block .fa,
            .banner-wrapper .page-title h1,
            .single-post .blog-wrapper .blog-content .posted-on time:hover, 
            .single-post .blog-wrapper .blog-content .comment-value a:hover,
            .comments .time .reply a,
            .loader-container .fa,
            .site-footer a:hover,
            .address-block li a:hover,
            .single-post .blog-wrapper .blog-content .posted-on a:hover,
            .layer-2 a:hover h1, 
            .layer-2 a:focus h1,
            #photo-gallery .gallery-title a:hover h4,
            #photo-gallery .gallery-title a:focus h4,
            .portfolio-title a:hover h4,
            .portfolio-title a:focus h4,
            #secondary .widget-title,
            .widget_recent_comments li:before, 
            .widget_pages ul li a:before, 
            .widget_nav_menu ul li a:before, 
            .widget_archive ul li a:before, 
            .widget_recent_entries ul li a:before,
            #secondary a:hover,
            #secondary a:focus,
            #instagram figcaption a:hover h5, 
            #instagram figcaption a:focus h5,
            #site-header .site-title a:hover, 
            #site-header .site-title a:focus,
            #masthead .site-title a:before,
            a,
            .woocommerce ul.products li.product a, 
            .woocommerce ul.products li.product .price, 
            .woocommerce nav.woocommerce-pagination ul li a:focus, 
            .woocommerce nav.woocommerce-pagination ul li a:hover, 
            .woocommerce nav.woocommerce-pagination ul li span.current, 
            .woocommerce ul.products li.product a:hover h2, 
            .product_meta a, a.woocommerce-review-link, 
            .woocommerce p.stars a, 
            .woocommerce .star-rating::before, 
            .woocommerce .star-rating, 
            .woocommerce-message::before,
            #photo-gallery span.view-gallery a:hover,
			#photo-gallery span.number-of-photos a:hover, 
			#photo-gallery span.number-of-photos a:focus, 
			#photo-gallery span.view-gallery a:hover, 
			#photo-gallery span.view-gallery a:focus, 
			.portfolio-title a:hover h4, 
			.portfolio-title a:focus h4, 
			.tp-portfolio .box small a:hover, 
			.tp-portfolio .box small a:focus {
                color: ' . esc_attr( $theme_color ) . ';
            }
            .cycle-pager .cycle-pager-active {
                color: #215079 ;
            }
            .backtotop,
            .btn.fill .btn-show,
            li .wide, 
            li .boxed,
            form .btn-contact,
            .woocommerce span.onsale,
            .woocommerce #respond input#submit, .woocommerce a.button, 
            .woocommerce button.button, 
            .woocommerce input.button, 
            .woocommerce #respond input#submit.alt, 
            .woocommerce a.button.alt, 
            .woocommerce button.button.alt, 
            .woocommerce input.button.alt {
                background-color: ' . esc_attr( $theme_color ) . ';
            }
            .portfolio-filter li .active,
            .portfolio-filter li a:hover {
                color: ' . esc_attr( $theme_color ) . ';
                border-bottom: 3px solid ' . esc_attr( $theme_color ) . ';
            }
            .blog-content blockquote .fa {
                color: ' . esc_attr( $theme_color ) . ';
                border: 1px solid ' . esc_attr( $theme_color ) . ';
            }
            .form-group input:focus, 
            .form-group textarea:focus,
            .widget select:focus,
            #photo-gallery span.view-gallery a:hover .fa, 
			#photo-gallery span.view-gallery a:focus .fa {
                border-color: ' . esc_attr( $theme_color ) . ';
            }
            .btn.border {
                border: 2px solid ' . esc_attr( $theme_color ) . ';
                color: ' . esc_attr( $theme_color ) . ';
            }
            .btn.border:hover,
            .widget.widget_meta li a:hover, 
            #secondary .widget.widget_meta li a:hover,
            .calendar_wrap caption {
                background-color: ' . esc_attr( $theme_color ) . ';
                color: #fff;
            }
        ';
		wp_add_inline_style( 'photo-fusion-pro-style' , $css );
	} 
	else {
		wp_add_inline_style( 'photo-fusion-pro-color-layout-'. esc_attr( $options['color_layout_options'] ) , $css );
	}
}
add_action( 'wp_enqueue_scripts', 'photo_fusion_pro_inline_css', 10 );


/**
 * Reset all options
 *
 * @since Photo Fusion Pro 1.0
 *
 * @param bool $checked Whether the reset is checked.
 * @return bool Whether the reset is checked.
 */
function photo_fusion_pro_reset_options() {
	$options = photo_fusion_pro_get_theme_options();
	if ( true === $options['reset_options'] ) {
		// Reset custom theme options.
		set_theme_mod( 'photo_fusion_pro_theme_options', array() );
		// Reset custom header and backgrounds.
		remove_theme_mod( 'header_image' );
		remove_theme_mod( 'header_image_data' );
		remove_theme_mod( 'background_image' );
		remove_theme_mod( 'background_color' );
    }
  	else {
	    return false;
  	}

}
add_action( 'customize_save_after', 'photo_fusion_pro_reset_options' );