<?php
/**
 * Photo Fusion Pro counter options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */

// Add cournter enable section
$wp_customize->add_section( 'photo_fusion_pro_counter_section', array(
	'title'             => esc_html__( 'Counter','photo-fusion-pro' ),
	'description'       => esc_html__( 'Counter section options.', 'photo-fusion-pro' ),
	'panel'             => 'photo_fusion_pro_sections_panel'
) );

// Add cournter enable setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_enable]', array(
	'default'           => $options['counter_enable'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[counter_enable]', array(
	'label'             => esc_html__( 'Enable on', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_counter_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_enable_disable_options()
) );

// Add cournter content type setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_content_type]', array(
	'default'           => $options['counter_content_type'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[counter_content_type]', array(
	'label'           => esc_html__( 'Content Type', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_counter_section',
	'type'            => 'select',
	'active_callback' => 'photo_fusion_pro_is_counter_active',
	'choices'         => photo_fusion_pro_counter_content_type()
) );

$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_bg_image]', array(
	'sanitize_callback' => 'photo_fusion_pro_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'photo_fusion_pro_theme_options[counter_bg_image]', array(
	'active_callback' => 'photo_fusion_pro_is_counter_content_demo_inactive',
	'label'           => esc_html__( 'Background Image', 'photo-fusion-pro' ),
	'description'	  => esc_html__( 'Upload background image for counter section. Recommended image size is 1350x760 px', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_counter_section',
) ) );


// Add blog number setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_count]', array(
	'default'           => $options['counter_count'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range',
	'validate_callback' => 'photo_fusion_pro_validate_no_of_counter_count'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[counter_count]', array(
	'label'           => esc_html__( 'Number of features.', 'photo-fusion-pro' ),
	'description'     => esc_html__( 'Notice: Please refresh after the number of features is set to see the effects.', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_counter_section',
	'type'            => 'number',
	'active_callback' => 'photo_fusion_pro_is_counter_content_demo_inactive',
	'input_attrs'     => array(
		'max' => 4,
		'min' => 1
	)
) );

for ( $i=1; $i <= $options['counter_count']; $i++ ) {
	// Show cournter icon setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_icon_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[counter_icon_'.$i.']', array(
	'description'       => sprintf( esc_html__( 'Example fa-cloud-upload see more at %1$s Font awesome %2$s.', 'photo-fusion-pro' ), '<a target="_blank" href="' . esc_url( 'http://fontawesome.io/icons/' ) . '">', '</a>' ),
		'section'         => 'photo_fusion_pro_counter_section',
		'active_callback' => 'photo_fusion_pro_is_counter_content_demo_inactive',
	) );

	// Show cournter name setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_name_'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[counter_name_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Name #%s', 'photo-fusion-pro' ), $i ),
		'section'         => 'photo_fusion_pro_counter_section',
		'active_callback' => 'photo_fusion_pro_is_counter_content_demo_inactive',
	) );

	// Show cournter count setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_count_'.$i.']', array(
		'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range'
	) );

	$wp_customize->add_control( 'photo_fusion_pro_theme_options[counter_count_'.$i.']', array(
		'label'           => sprintf( esc_html__( 'Count #%s', 'photo-fusion-pro' ), $i ),
		'section'         => 'photo_fusion_pro_counter_section',
		'active_callback' => 'photo_fusion_pro_is_counter_content_demo_inactive',
		'type'				=> 'number',
		'input_attrs'		=> array(
			'min' => 0
			)
	) );

	// Featues custom hr setting and control
	$wp_customize->add_setting( 'photo_fusion_pro_theme_options[counter_content_custom_hr'.$i.']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new photo_fusion_pro_Customize_Horizontal_Line( $wp_customize, 'photo_fusion_pro_theme_options[counter_content_custom_hr'.$i.']',
		array(
			'section'         => 'photo_fusion_pro_counter_section',
			'active_callback' => 'photo_fusion_pro_is_counter_content_demo_inactive',
			'type'			  => 'hr'
	) ) );
}

