<?php
/**
 * Photo Fusion Pro options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */


/**
 * Enable options of the defined section
 * @return array Enable options
 */
function photo_fusion_pro_enable_options() {
	$photo_fusion_pro_enable_options = array(
		'static-frontpage' => esc_html__( 'Static Frontpage', 'photo-fusion-pro' ),
		'entire-site'      => esc_html__( 'Entire Site', 'photo-fusion-pro' ),
		'disabled'         => esc_html__( 'Disabled', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_enable_options', $photo_fusion_pro_enable_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Common content types
 * @return array Content types
 */
function photo_fusion_pro_content_type() {
	$photo_fusion_pro_content_type = array(
		'demo' 		=> esc_html__( 'Demo', 'photo-fusion-pro' ),
		'page'		=> esc_html__( 'Page', 'photo-fusion-pro' ),
		'post'		=> esc_html__( 'Post', 'photo-fusion-pro' ),
		'category'  => esc_html__( 'Category', 'photo-fusion-pro' ),
	); 

	$output = apply_filters( 'photo_fusion_pro_content_type', $photo_fusion_pro_content_type );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Enable options of the slider section
 * @return array Enable options
 */
function photo_fusion_pro_enable_disable_options() {
	$photo_fusion_pro_enable_disable_options = array(
		'static-frontpage' => esc_html__( 'Static Frontpage', 'photo-fusion-pro' ),
		'disabled'         => esc_html__( 'Disabled', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_enable_disable_options', $photo_fusion_pro_enable_disable_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Slider effects
 * @return array Slider effects
 */
function photo_fusion_pro_slider_effect() {
	$photo_fusion_pro_slider_effect = array(
		'scrollHorz' => esc_html__( 'Scroll Horizontal', 'photo-fusion-pro' ),
		'scrollVert' => esc_html__( 'Scroll Vertical', 'photo-fusion-pro' ),
		'fadeout'    => esc_html__( 'Fade Out', 'photo-fusion-pro' ),
		'flipHorz'   => esc_html__( 'Flip Horizontal', 'photo-fusion-pro' ),
		'flipVert'   => esc_html__( 'Flip Vertical', 'photo-fusion-pro' ),
		'shuffle'    => esc_html__( 'Shuffle', 'photo-fusion-pro' ),
	);

	$output =  apply_filters( 'photo_fusion_pro_slider_effect', $photo_fusion_pro_slider_effect );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Blog content types
 * @return array Content types
 */
function photo_fusion_pro_blog_content_type() {
	$photo_fusion_pro_blog_content_type = array(
		'demo'        => esc_html__( 'Demo', 'photo-fusion-pro' ),
		'post'        => esc_html__( 'Choose Posts', 'photo-fusion-pro' ),
		'recent-post' => esc_html__( 'Recent Posts', 'photo-fusion-pro' ),
		'category'    => esc_html__( 'Show by Category', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_blog_content_type', $photo_fusion_pro_blog_content_type );

	return $output;
}


/**
 * List of Font Awesome contact related icons
 * @return array Font Awesome icons
 */
function photo_fusion_pro_contact_info_icons() {
	$photo_fusion_pro_contact_info_icons = array(
		'fa-facebook'        => 'f09a',
		'fa-twitter'         => 'f099',
		'fa-google-plus '    => 'f0d5',
		'fa-location-arrow ' => 'f124',
		'fa-instagram '      => 'f16d',
		'fa-phone '          => 'f095',
		'fa-phone-square '   => 'f098',
		'fa-envelope '       => 'f0e0',
	);

	$output = apply_filters( 'photo_fusion_pro_contact_info_icons', $photo_fusion_pro_contact_info_icons );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Returns an array of FA contact related icons
 *
 * @since  Photo Fusion Pro 1.0
 * @access public
 * @return array An array of font awesome icons
 */
function photo_fusion_pro_contact_info_icons_choices() {

	$icons = array();
	$contact_icons = photo_fusion_pro_contact_info_icons();
	foreach ( $contact_icons as $class => $code )
		$icons[ $class ] = "&#x{$code};";

	return $icons;
}


/**
 * List of pagination types
 * @return array Pagination types
 */
function photo_fusion_pro_pagination_type() {
	$photo_fusion_pro_pagination_type = array(
		'numeric'         => esc_html__( 'Numeric', 'photo-fusion-pro' ),
		'older-newer'     => esc_html__( 'Older/Newer', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_pagination_type', $photo_fusion_pro_pagination_type );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * List of color layout
 * @return array Color layout options
 */
function photo_fusion_pro_color_theme_type() {
	$photo_fusion_pro_color_theme_type = array(
		'color-theme'  		=> esc_html__( 'Color Theme', 'photo-fusion-pro' ),
		'color-picker'     	=> esc_html__( 'Color Picker', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_color_theme_type', $photo_fusion_pro_color_theme_type );

	return $output;
}

/**
 * List of color layout
 * @return array Color layout options
 */
function photo_fusion_pro_color_layouts() {
	$photo_fusion_pro_color_layouts = array(
		'default'  		=> esc_html__( 'Default', 'photo-fusion-pro' ),
		'blue'      	=> esc_html__( 'Blue', 'photo-fusion-pro' ),
		'dark-green'    => esc_html__( 'Dark Green', 'photo-fusion-pro' ),
		'green'    		=> esc_html__( 'Green', 'photo-fusion-pro' ),
		'yellow'     	=> esc_html__( 'Yellow', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_color_layouts', $photo_fusion_pro_color_layouts );

	return $output;
}

/**
 * Archive Content types
 * @return array Pagination types
 */
function photo_fusion_pro_loader_type() {
	$photo_fusion_pro_loader_type = array(
		'image-gif' => esc_html__( 'Image/Gif', 'photo-fusion-pro' ),
		'icon'     => esc_html__( 'Icon', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_loader_type', $photo_fusion_pro_loader_type );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}


/**
 * Sidebar position
 * @return array Sidbar positions
 */
function photo_fusion_pro_sidebar_position() {
	$photo_fusion_pro_sidebar_position = array(
		'right-sidebar' => esc_html__( 'Right', 'photo-fusion-pro' ),
		'left-sidebar'  => esc_html__( 'Left', 'photo-fusion-pro' ),
		'no-sidebar'    => esc_html__( 'No Sidebar', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_sidebar_position', $photo_fusion_pro_sidebar_position );

	return $output;
}

/**
 * Sidebar position
 * @return array Sidbar positions
 */
function photo_fusion_pro_gallery_with_gap() {
	$photo_fusion_pro_sidebar_position = array(
		'gallery-with-gap' 	=> esc_html__( 'With Gap', 'photo-fusion-pro' ),
		'gallery-no-gap'  	=> esc_html__( 'No Gap', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_sidebar_position', $photo_fusion_pro_sidebar_position );

	return $output;
}


/**
 * Site Layout
 * @return array Sidbar positions
 */
function photo_fusion_pro_site_layout() {
	$photo_fusion_pro_site_layout = array(
		'wide'  => esc_html__( 'Wide', 'photo-fusion-pro' ),
		'boxed' => esc_html__( 'Boxed', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_site_layout', $photo_fusion_pro_site_layout );

	return $output; 
}


/*New Added For Photo Fusion*/

/**
 * photo gallery source
 */
function photo_fusion_pro_photo_gallery_source() {
	$photo_fusion_pro_pg_source = array(
		'demo'  	=> esc_html__( 'Demo', 'photo-fusion-pro' ),
		'category' 	=> esc_html__( 'Category Posts', 'photo-fusion-pro' ),
		'category-list' => esc_html__( 'Category List', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_pg_source', $photo_fusion_pro_pg_source );

	return $output;
}

/*New Added For Photo Fusion*/

/**
 * photo gallery source
 */
function photo_fusion_pro_portfolio_source() {
	$photo_fusion_pro_pf_source = array(
		'demo'  	=> esc_html__( 'Demo', 'photo-fusion-pro' ),
		'category' 	=> esc_html__( 'Category Posts', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_pf_source', $photo_fusion_pro_pf_source );

	return $output;
}

/**
 * Site Layout
 * @return array Sidbar positions
 */
function photo_fusion_pro_photo_gallery_image_layout() {
	$photo_fusion_pro_about_image_layout = array(
		'grid'  	=> esc_html__( 'Grid Box', 'photo-fusion-pro' ),
		'masonry' 	=> esc_html__( 'Masonry', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_about_image_layout', $photo_fusion_pro_about_image_layout );

	return $output;
}

/**
 * Counter content types
 * @return array Content types
 */
function photo_fusion_pro_counter_content_type() {
	$photo_fusion_pro_counter_content_type = array(
		'demo'               => esc_html__( 'Demo', 'photo-fusion-pro' ),
		'custom'           => esc_html__( 'Custom', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_counter_content_type', $photo_fusion_pro_counter_content_type );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * Returns list of social icons currently supported
*/
function photo_fusion_pro_get_social_icons_list() {
	$photo_fusion_pro_social_icons_list = array(
		'facebook_link'		=> array(
			'genericon_class' 	=> 'facebook-alt',
			'label' 			=> esc_html__( 'Facebook', 'photo-fusion-pro' )
			),
		'twitter_link'		=> array(
			'genericon_class' 	=> 'twitter',
			'label' 			=> esc_html__( 'Twitter', 'photo-fusion-pro' )
			),
		'googleplus_link'	=> array(
			'genericon_class' 	=> 'googleplus-alt',
			'label' 			=> esc_html__( 'Googleplus', 'photo-fusion-pro' )
			),
		'email_link'		=> array(
			'genericon_class' 	=> 'mail',
			'label' 			=> esc_html__( 'Email', 'photo-fusion-pro' )
			),
		'wordpress_link'	=> array(
			'genericon_class' 	=> 'wordpress',
			'label' 			=> esc_html__( 'WordPress', 'photo-fusion-pro' )
			),
		'linkedin_link'		=> array(
			'genericon_class' 	=> 'linkedin',
			'label' 			=> esc_html__( 'LinkedIn', 'photo-fusion-pro' )
			),
		'youtube_link'		=> array(
			'genericon_class' 	=> 'youtube',
			'label' 			=> esc_html__( 'YouTube', 'photo-fusion-pro' )
			),
		'instagram_link'	=> array(
			'genericon_class' 	=> 'instagram',
			'label' 			=> esc_html__( 'Instagram', 'photo-fusion-pro' )
			),
		'skype_link'		=> array(
			'genericon_class' 	=> 'skype',
			'label' 			=> esc_html__( 'Skype', 'photo-fusion-pro' )
			),
		'dropbox_link'		=> array(
			'genericon_class' 	=> 'dropbox',
			'label' 			=> esc_html__( 'DropBox', 'photo-fusion-pro' ),
			),
		'phone_link'		=> array(
			'genericon_class' 	=> 'phone',
			'label' 			=> esc_html__( 'Phone', 'photo-fusion-pro' ),
			),
		'handset_link'		=> array(
			'genericon_class' 	=> 'handset',
			'label' 			=> esc_html__( 'Handset', 'photo-fusion-pro' ),
			),
	);

	return apply_filters( 'photo_fusion_pro_social_icons_list', $photo_fusion_pro_social_icons_list );
}

/**
 * Returns list of typography
*/
function photo_fusion_pro_typography_options(){

    $choices = array(
      'poppins'         => esc_html__( 'POPPINS AND COURGETTE FONT', 'photo-fusion-pro' ),
      'roboto'          => esc_html__( 'ROBOTO AND MONTSERRAT FONT', 'photo-fusion-pro' ),
      'raleway'         => esc_html__( 'RALEWAY AND POPPINS FONT', 'photo-fusion-pro' ),
      'courgette'       => esc_html__( 'COURGETTE AND ROBOTO FONT', 'photo-fusion-pro' ),
      'montserrat'      => esc_html__( 'MONTSERRAT FONT', 'photo-fusion-pro' ),
      'open-sans'      	=> esc_html__( 'OPEN SANS SERIF', 'photo-fusion-pro' ),
    );
    $output = apply_filters( 'photo_fusion_pro_typography_options', $choices );
    if ( ! empty( $output ) ) {
      ksort( $output );
    }
    return $output;

}

/**
 * About Section Source
 * @return array Enable options
 */
function photo_fusion_pro_about_source_options() {
	$photo_fusion_pro_about_source_options = array(
		'demo' 		=> esc_html__( 'Demo', 'photo-fusion-pro' ),
		'page'      => esc_html__( 'Page', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_about_source_options', $photo_fusion_pro_about_source_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}

/**
 * About Section Source
 * @return array Enable options
 */
function photo_fusion_pro_map_options() {
	$photo_fusion_pro_map_options = array(
		'embed' 		=> esc_html__( 'Embed Code', 'photo-fusion-pro' ),
		'shortcode'     => esc_html__( 'Plugin Shortcode', 'photo-fusion-pro' ),
	);

	$output = apply_filters( 'photo_fusion_pro_map_options', $photo_fusion_pro_map_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}