<?php
/**
 * Custom Info Widget
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */

if ( ! class_exists( 'photo_fusion_pro_Info_Widget' ) ) :
/**
 * Custom Info class.
 *
 * @since 1.0
 */
class photo_fusion_pro_Info_Widget extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$this->defaults = array(
			'title'    => esc_html__( 'Contact Information', 'photo-fusion-pro' ),
		);
		$widget_ops = array(
			'classname' => 'photo_fusion_pro_info_widget',
			'description' => esc_html__( 'A widget to show basic informations with icons.', 'photo-fusion-pro' ),
		);
		parent::__construct( 'photo_fusion_pro_info_widget', esc_html__( 'TP : Custom Info','photo-fusion-pro' ), $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		// outputs the content of the widget
		if ( ! isset( $args['widget_id'] ) ) {
			$args['widget_id'] = $this->id;
		}
		$title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';

		echo $args['before_widget'];
			if ( ! empty( $title ) ) {
				echo $args['before_title'] . esc_html( $title ) . $args['after_title'];
			}


		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3; ?>
		<ul class="address-block">
			<?php
			for ( $i=1; $i <= $number ; $i++ ) {
				$contact_value = ( ! empty( $instance['contact_value' . '-' . $i] ) ) ? $instance['contact_value' . '-' . $i] : '';
				$icon = ( ! empty( $instance['icon' . '-' . $i] ) ) ? $instance['icon' . '-' . $i] : ''; ?>
	         <li><i class="fa <?php echo esc_attr( $icon );?>"></i><?php echo esc_html( $contact_value );?></li>
			<?php } ?>
     </ul>
		<?php
		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, $this->defaults );
		
		$number = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3;

		$icons  = photo_fusion_pro_contact_info_icons_choices();
		$title     = isset( $instance['title'] ) ? esc_html( $instance['title'] ) : '';
	   ?>

	   <p>
		   <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_html_e( 'Title:', 'photo-fusion-pro' ); ?></label>
		   <input class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
	   </p>

	   <p>
	   	<label for="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>"><?php esc_html_e( 'Number of fields to show:', 'photo-fusion-pro' ); ?></label>
	   	<input class="tiny-text" id="<?php echo esc_attr( $this->get_field_id( 'number' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'number' ) ); ?>" type="number" step="1" min="1" value="<?php echo absint( $number ); ?>" size="3" />
	   </p>
	   <?php for ( $i=1; $i <= $number; $i++ ) {
	   	$icon_selected = isset( $instance['icon'. '-' . $i ] ) ? $instance['icon' . '-' . $i ] : '';?>
		   <p>
		   	<label for="<?php echo esc_attr( $this->get_field_id( 'icon' . '-' . $i ) ); ?>"><?php printf( esc_html__( 'Select Icon %s :', 'photo-fusion-pro' ), $i ); ?></label>
		   	<select class="photo-fusion-pro-contact-info-widget" id="<?php echo esc_attr( $this->get_field_id( 'icon' . '-' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'icon' . '-' . $i ) ); ?>">
		   		<option value="0"><?php esc_html_e( '&mdash; Select &mdash;', 'photo-fusion-pro' ); ?></option>
		   		<?php foreach ( $icons as $icon => $value ) : ?>
		   			<option value="<?php echo esc_attr( $icon ); ?>" <?php selected( $icon_selected, $icon ); ?>>
		   				<?php echo esc_html( $value ) . ' ' . esc_attr( $icon ); ?>
		   			</option>
		   		<?php endforeach; ?>
		   	</select>
		   </p>
		   <?php $contact_value = ! empty( $instance['contact_value'. '-' . $i] ) ? $instance['contact_value' . '-' . $i] : '';?>
		   <p>
		   	<label for="<?php echo esc_attr( $this->get_field_id( 'contact_value' . '-' . $i ) ) . '-' . $i; ?>"><?php printf( esc_html__( 'Contact Info %s :', 'photo-fusion-pro' ), $i ); ?></label>
		   	<textarea class="widefat" rows="2" cols="10" id="<?php echo esc_attr( $this->get_field_id('contact_value' . '-' . $i ) ); ?>" name="<?php echo esc_attr( $this->get_field_name('contact_value' . '-' . $i) ); ?>"><?php echo esc_textarea( $contact_value ); ?></textarea>
		   </p>
	   <?php }?>

	   <?php
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 */
	public function update( $new_instance, $old_instance ) {
		// processes widget options to be saved
		$instance = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );
		$instance['number'] = (int) $new_instance['number'];
		for ( $i=1; $i <= $instance['number'] ; $i++ ) {
			$instance['icon' . '-' . $i] = esc_attr( $new_instance['icon' . '-' . $i] );

			if ( current_user_can( 'unfiltered_html' ) ) {
				$instance['contact_value' . '-' . $i] = $new_instance['contact_value' . '-' . $i];
			} else {
				$instance['contact_value' . '-' . $i] = wp_kses_post( $new_instance['contact_value' . '-' . $i] );
			}
		}
		return $instance;
	}
}
endif;